componenttools.yield_components_grouped_by_preprolated_duration
===============================================================

.. autofunction:: abjad.tools.componenttools.yield_components_grouped_by_preprolated_duration.yield_components_grouped_by_preprolated_duration
